@@ -35,6 +35,7 @@
 #include "DkUtils.h"
 
 #pragma warning(push, 0) // no warnings from includes - begin
+#include <QDir>
 #include <QImage>
 #include <QObject>
 #include <QRegularExpression>
@@ -336,27 +337,9 @@ QImage DkImageContainer::imageScaledToHeight(int height)
     return sImg;
 }
 
-QImage DkImageContainer::imageScaledToWidth(int width)
-{
-    // check cache first
-    for (const QImage &img : scaledImages) {
-        if (img.width() == width)
-            return img;
-    }
-
-    // cache it
-    QImage sImg = image().scaledToWidth(width, Qt::SmoothTransformation);
-    scaledImages << sImg;
-
-    // clean up
-    if (scaledImages.size() > 10)
-        scaledImages.pop_front();
-
-    return sImg;
-}
-
 void DkImageContainer::setImage(const QImage &img, const QString &editName)
 {
+    scaledImages.clear();
     getLoader()->setEditImage(img, editName);
     mEdited = true;
 }
@@ -490,7 +473,7 @@ DkImageContainer::loadImageIntern(const QString &filePath, QSharedPointer<DkBasi
     try {
         loader->loadGeneral(filePath, fileBuffer, true, false);
     } catch (...) {
-        qWarning() << "Unknown error in DkImageContainer::lfoadImageIntern";
+        qWarning() << "Unhandled exception in loadGeneral()";
     }
 
     return loader;
