@@ -237,8 +237,6 @@ bool DkImageLoader::loadDir(const QString &newDirPath, bool scanRecursive)
     if (mFolderUpdated && newDirPath == mCurrentDir) {
         mFolderUpdated = false;
         QFileInfoList files = getFilteredFileInfoList(newDirPath,
-                                                      mIgnoreKeywords,
-                                                      mKeywords,
                                                       mFolderFilterString); // this line takes seconds if you have lots of files and slow loading (e.g. network)
 
         // might get empty too (e.g. someone deletes all images)
@@ -276,15 +274,8 @@ bool DkImageLoader::loadDir(const QString &newDirPath, bool scanRecursive)
             files = updateSubFolders(mCurrentDir);
         else
             files = getFilteredFileInfoList(mCurrentDir,
-                                            mIgnoreKeywords,
-                                            mKeywords,
                                             mFolderFilterString); // this line takes seconds if you have lots of files and slow loading (e.g. network)
 
-        if (files.empty()) {
-            emit showInfoSignal(tr("%1 \n does not contain any image").arg(mCurrentDir), 4000); // stop showing
-            return false;
-        }
-
         // ok new folder, this should speed-up loading
         mImages.clear();
 
@@ -689,12 +680,6 @@ QVector<QSharedPointer<DkImageContainerT>> DkImageLoader::getImages()
     return mImages;
 }
 
-void DkImageLoader::setImages(QVector<QSharedPointer<DkImageContainerT>> images)
-{
-    mImages = images;
-    emit updateDirSignal(images);
-}
-
 /**
  * Loads the first file of the current directory.
  **/
@@ -751,14 +736,6 @@ bool DkImageLoader::unloadFile()
     return true;
 }
 
-/**
- * Convenience function see @activate.
- **/
-void DkImageLoader::deactivate()
-{
-    activate(false);
-}
-
 /**
  * Activates or deactivates the loader.
  * If activated, the directory is indexed & the current image is loaded.
@@ -1009,7 +986,7 @@ void DkImageLoader::saveFileWeb(const QImage &saveImg)
     QFileInfo saveFileInfo;
 
     if (hasFile()) {
-        saveFileInfo = QFileInfo(getSavePath(), fileName());
+        saveFileInfo = QFileInfo(mCurrentDir, fileName());
         qDebug() << "save path: " << saveFileInfo.absoluteFilePath();
     }
 
@@ -1111,7 +1088,7 @@ void DkImageLoader::saveUserFileAs(const QImage &saveImg, bool silent)
     QFileInfo saveFileInfo;
 
     if (hasFile()) {
-        saveFileInfo = QFileInfo(getSavePath(), fileName());
+        saveFileInfo = QFileInfo(mCurrentDir, fileName());
 
         int filterIdx = -1;
 
@@ -1502,7 +1479,7 @@ void DkImageLoader::rotateImage(double angle)
         try {
             // Set orientation in exif data
             if (!metaData->isJpg())
-                metaData->setThumbnail(thumb);
+                metaData->setThumbnail(thumb); // FIXME: creates wrong thumb for non-JPG formats supporting EXIF! (PNG)
             metaData->setOrientation(qRound(angle));
             metaDataSet = true;
 
@@ -1531,60 +1508,6 @@ void DkImageLoader::rotateImage(double angle)
     }
 }
 
-/**
- * Restores files that were destroyed by the Exiv2 lib.
- * If a watch (or some other read lock) is on a file, the
- * Exiv2 lib is known do damage the files on Windows.
- * This function restores these files.
- * @param fileInfo the file to be restored.
- * @return bool true if the file could be restored.
- **/
-bool DkImageLoader::restoreFile(const QString &filePath)
-{
-    QFileInfo fInfo(filePath);
-    QStringList files = fInfo.dir().entryList();
-    QString fileName = fInfo.fileName();
-    QRegularExpression filePattern(fileName + "[0-9]+");
-    QString backupFileName;
-
-    // if exif crashed it saved a backup file with the format: filename.png1232
-    for (int idx = 0; idx < files.size(); idx++) {
-        if (filePattern.match(files[idx]).hasMatch()) {
-            backupFileName = files[idx];
-            break;
-        }
-    }
-
-    if (backupFileName.isEmpty()) {
-        qDebug() << "I could not locate the backup file...";
-        return true;
-    }
-
-    // delete the destroyed file
-    QFile file(filePath);
-    QFile backupFile(fInfo.absolutePath() + QDir::separator() + backupFileName);
-
-    if (file.size() == 0 || file.size() <= backupFile.size()) {
-        if (!file.remove()) {
-            // ok I did not destroy the original file - so delete the back-up
-            // -> this reverts the file - but otherwise we spam to the disk
-            // actions reverted here include meta data saving
-            if (file.size() != 0)
-                return backupFile.remove();
-
-            qDebug() << "I could not remove the file...";
-            return false;
-        }
-    } else {
-        qDebug() << "non-empty file: " << fileName << " I won't delete it...";
-        qDebug() << "file size: " << file.size() << " back-up file size: " << backupFile.size();
-        return false;
-    }
-
-    // now
-    return backupFile.rename(fInfo.absoluteFilePath());
-}
-
 /**
  * Reloads the file index if the directory was edited.
  * @param path the path to the current directory
@@ -1707,9 +1630,7 @@ QFileInfoList DkImageLoader::updateSubFolders(const QString &rootDirPath)
     // find the first subfolder that has images
     for (int idx = 0; idx < mSubFolders.size(); idx++) {
         mCurrentDir = mSubFolders[idx];
-        files = getFilteredFileInfoList(mCurrentDir,
-                                        mIgnoreKeywords,
-                                        mKeywords); // this line takes seconds if you have lots of files and slow loading (e.g. network)
+        files = getFilteredFileInfoList(mCurrentDir); // this line takes seconds if you have lots of files and slow loading (e.g. network)
         if (!files.empty())
             break;
     }
@@ -1747,9 +1668,8 @@ int DkImageLoader::getSubFolderIdx(int fromIdx, bool forward) const
             return -1;
 
         QDir cDir = mSubFolders[checkIdx];
-        QFileInfoList cFiles = getFilteredFileInfoList(cDir.absolutePath(),
-                                                       mIgnoreKeywords,
-                                                       mKeywords); // this line takes seconds if you have lots of files and slow loading (e.g. network)
+        QFileInfoList cFiles =
+            getFilteredFileInfoList(cDir.absolutePath()); // this line takes seconds if you have lots of files and slow loading (e.g. network)
         if (!cFiles.empty()) {
             idx = checkIdx;
             break;
@@ -1841,11 +1761,9 @@ void DkImageLoader::updateCacher(QSharedPointer<DkImageContainerT> imgC)
  * directory or if the directory is in the net.
  * Currently the file list is sorted according to the system specification.
  * @param dir the directory to load the file list from.
- * @param ignoreKeywords if one of these keywords is in the file name, the file will be ignored.
- * @param keywords if one of these keywords is not in the file name, the file will be ignored.
  * @return QStringList all filtered files of the current directory.
  **/
-QFileInfoList DkImageLoader::getFilteredFileInfoList(const QString &dirPath, QStringList ignoreKeywords, QStringList keywords, QString folderKeywords) const
+QFileInfoList DkImageLoader::getFilteredFileInfoList(const QString &dirPath, QString folderKeywords) const
 {
     DkTimer dt;
 
@@ -1918,16 +1836,6 @@ QFileInfoList DkImageLoader::getFilteredFileInfoList(const QString &dirPath, QSt
         }
     }
 
-    // remove files that contain ignore keywords
-    for (int idx = 0; idx < ignoreKeywords.size(); idx++) {
-        QRegularExpression exp = QRegularExpression("^((?!" + ignoreKeywords[idx] + ").)*$", QRegularExpression::CaseInsensitiveOption);
-        fileList = fileList.filter(exp);
-    }
-
-    for (int idx = 0; idx < keywords.size(); idx++) {
-        fileList = fileList.filter(keywords[idx], Qt::CaseInsensitive);
-    }
-
     if (folderKeywords != "") {
         QStringList filterList = fileList;
         fileList = DkUtils::filterStringList(folderKeywords, filterList);
@@ -2015,18 +1923,6 @@ QString DkImageLoader::getCopyPath() const
         return mCopyDir;
 }
 
-/**
- * Returns the directory where files are saved to.
- * @return QDir the directory where the user saved the last file to.
- **/
-QString DkImageLoader::getSavePath() const
-{
-    if (mSaveDir.isEmpty() || !QDir(mSaveDir).exists())
-        return mCurrentDir;
-    else
-        return mSaveDir;
-}
-
 /**
  * Returns if an image is loaded currently.
  * @return bool true if an image is loaded.
@@ -2062,18 +1958,6 @@ void DkImageLoader::redo()
     mCurrentImage->redo();
 }
 
-/**
- * Returns the currently loaded image.
- * @return QImage the current image
- **/
-QImage DkImageLoader::getImage()
-{
-    if (!mCurrentImage)
-        return QImage();
-
-    return mCurrentImage->image();
-}
-
 /**
  * @brief Returns the currently loaded pixmap. May differ from the image returned by getImage()
  * in case the pixmap represents a meta modification, like after rotating it.
@@ -2091,57 +1975,6 @@ QImage DkImageLoader::getPixmap()
     return mCurrentImage->getLoader()->pixmap();
 }
 
-bool DkImageLoader::dirtyTiff()
-{
-    if (!mCurrentImage)
-        return false;
-
-    return mCurrentImage->getLoader()->isDirty();
-}
-
-QStringList DkImageLoader::ignoreKeywords() const
-{
-    return mIgnoreKeywords;
-}
-
-void DkImageLoader::setIgnoreKeywords(const QStringList &ignoreKeywords)
-{
-    mIgnoreKeywords = ignoreKeywords;
-}
-
-void DkImageLoader::appendIgnoreKeyword(const QString &keyword)
-{
-    mIgnoreKeywords.append(keyword);
-}
-
-QStringList DkImageLoader::keywords() const
-{
-    return mKeywords;
-}
-
-void DkImageLoader::setKeywords(const QStringList &keywords)
-{
-    mKeywords = keywords;
-}
-
-void DkImageLoader::appendKeyword(const QString &keyword)
-{
-    mKeywords.append(keyword);
-}
-
-void DkImageLoader::loadLastDir()
-{
-    if (DkSettingsManager::param().global().recentFolders.empty())
-        return;
-
-    setDir(DkSettingsManager::param().global().recentFolders[0]);
-}
-
-void DkImageLoader::setFolderFilters(const QStringList &filter)
-{
-    setFolderFilter(filter.join(" "));
-}
-
 void DkImageLoader::setFolderFilter(const QString &filter)
 {
     mFolderFilterString = filter;
@@ -2149,16 +1982,6 @@ void DkImageLoader::setFolderFilter(const QString &filter)
     loadDir(mCurrentDir); // simulate a folder update operation
 }
 
-QString DkImageLoader::getFolderFilter()
-{
-    return mFolderFilterString;
-}
-
-QStringList DkImageLoader::getFolderFilters()
-{
-    return mFolderFilterString.split(" ");
-}
-
 /**
  * Sets the current directory to dir.
  * @param dir the directory to be loaded.
@@ -2173,15 +1996,6 @@ void DkImageLoader::setDir(const QString &dir)
         firstFile();
 }
 
-/**
- * Sets a new save directory.
- * @param dir the new save directory.
- **/
-void DkImageLoader::setSaveDir(const QString &dirPath)
-{
-    mSaveDir = dirPath;
-}
-
 /**
  * Sets the current image to a new image container.
  * @param img the loader's new image.
