@@ -31,9 +31,15 @@
 #include "DkSettings.h"
 #include "DkThumbs.h"
 #include "DkTimer.h"
+#include <cmath>
+
+#ifdef WITH_OPENCV
+#include <opencv2/core.hpp>
+#endif
 
 #pragma warning(push, 0) // no warnings from includes - begin
 #include <QBitmap>
+#include <QColorSpace>
 #include <QDebug>
 #include <QPainter>
 #include <QPixmap>
@@ -50,16 +56,6 @@ namespace nmc
 {
 // DkImage --------------------------------------------------------------------
 
-/**
- * Returns a string with the buffer size of an image.
- * @param img a QImage
- * @return QString a human readable string containing the buffer size
- **/
-QString DkImage::getBufferSize(const QImage &img)
-{
-    return getBufferSize(img.size(), img.depth());
-}
-
 /**
  * Returns a string with the buffer size of an image.
  * @param imgSize the image size
@@ -204,7 +200,7 @@ DkImage::resizeImage(const QImage &img, const QSize &newSize, double factor /* =
 
 bool DkImage::alphaChannelUsed(const QImage &img)
 {
-    if (img.format() != QImage::Format_ARGB32 && img.format() != QImage::Format_ARGB32)
+    if (img.format() != QImage::Format_ARGB32)
         return false;
 
     // number of used bytes per line
@@ -252,6 +248,11 @@ QImage DkImage::thresholdImage(const QImage &img, double thr, bool color)
 }
 
 QImage DkImage::rotateImage(const QImage &img, double angle)
+{
+    return rotateImageFast(img, angle);
+}
+
+QImage rotateImage(const QImage &img, double angle)
 {
     // compute new image size
     DkVector nSl((float)img.width(), (float)img.height());
@@ -290,6 +291,173 @@ QImage DkImage::rotateImage(const QImage &img, double angle)
     return imgR;
 }
 
+template<typename T>
+QImage transposeImage(const QImage &imgIn)
+{
+    QImage imgOut = QImage(imgIn.size().transposed(), imgIn.format());
+    imgOut.setColorTable(imgIn.colorTable());
+    imgOut.setColorSpace(imgIn.colorSpace());
+
+    const int h = imgIn.height();
+    const int w = imgIn.width();
+    const uchar *ptrIn = imgIn.constBits();
+    const int outBPL = imgOut.bytesPerLine();
+    const int inBPL = imgIn.bytesPerLine();
+    for (int i = 0; i < h; i++) {
+        const T *lineIn = reinterpret_cast<const T *>(ptrIn);
+        uchar *ptrOut = const_cast<uchar *>(imgOut.constBits() + i * sizeof(T));
+        for (int j = 0; j < w; j++) {
+            T *out = reinterpret_cast<T *>(ptrOut);
+            *out = lineIn[j];
+            ptrOut += outBPL;
+        }
+        ptrIn += inBPL;
+    }
+
+    return imgOut;
+}
+
+QImage transposeImage24(const QImage &imgIn)
+{
+    // NOTE: this implementation is more general (any depth that is multiple of 8 can be handled),
+    // but somehow several times slower than the above transposeImage.
+
+    QImage imgOut = QImage(imgIn.size().transposed(), imgIn.format());
+    imgOut.setColorTable(imgIn.colorTable());
+    imgOut.setColorSpace(imgIn.colorSpace());
+
+    const int h = imgIn.height();
+    const int w = imgIn.width();
+    const int outBPL = imgOut.bytesPerLine();
+    uchar *outBits = imgOut.bits();
+    const int charPerPixel = imgIn.depth() / CHAR_BIT;
+    for (int i = 0; i < h; i++) {
+        const uchar *ptrIn = imgIn.constScanLine(i);
+        uchar *ptrOut = outBits + i * charPerPixel;
+        for (int j = 0; j < w; j++) {
+            memcpy(ptrOut + outBPL * j, ptrIn + charPerPixel * j, charPerPixel);
+        }
+    }
+
+    return imgOut;
+}
+
+#ifdef WITH_OPENCV
+QImage rotateImageCVMat(const QImage &imgIn, cv::RotateFlags rot, int type)
+{
+    QSize size = rot == cv::ROTATE_180 ? imgIn.size() : imgIn.size().transposed();
+    QImage imgOut = QImage(size, imgIn.format());
+    imgOut.setColorTable(imgIn.colorTable());
+    imgOut.setColorSpace(imgIn.colorSpace());
+    imgOut.setDotsPerMeterX(imgIn.dotsPerMeterX());
+    imgOut.setDotsPerMeterY(imgIn.dotsPerMeterY());
+    imgOut.setDevicePixelRatio(imgIn.devicePixelRatio());
+    for (auto &key : imgIn.textKeys())
+        imgOut.setText(key, imgIn.text(key));
+
+    const cv::Mat matIn = cv::Mat(imgIn.height(), imgIn.width(), type, (uchar *)imgIn.constBits(), imgIn.bytesPerLine());
+    cv::Mat matOut = cv::Mat(imgOut.height(), imgOut.width(), type, imgOut.bits(), imgOut.bytesPerLine());
+
+    cv::rotate(matIn, matOut, rot);
+    return imgOut;
+}
+#endif
+
+QImage rotateImageFast(const QImage &img, double angle)
+{
+    angle = std::fmod(angle, 360);
+    if (angle < 0) {
+        angle += 360;
+    }
+
+    if (angle == 0) {
+        return img;
+    }
+
+    if (angle == 90 || angle == 180 || angle == 270) {
+        // Fast path
+
+#ifdef WITH_OPENCV
+        cv::RotateFlags rot{};
+        if (angle == 180) {
+            rot = cv::ROTATE_180;
+        } else if (angle == 90) {
+            rot = cv::ROTATE_90_CLOCKWISE;
+        } else {
+            rot = cv::ROTATE_90_COUNTERCLOCKWISE;
+        }
+
+        // The pixel depth matters, but the color interpretation does not.
+        switch (img.depth()) {
+        case 1:
+            return rotateImageCVMat(img.convertToFormat(QImage::Format_Indexed8), rot, CV_8U);
+        case 8:
+            return rotateImageCVMat(img, rot, CV_8U);
+        case 16:
+            return rotateImageCVMat(img, rot, CV_16U);
+        case 24:
+            return rotateImageCVMat(img, rot, CV_8UC3);
+        case 32:
+            return rotateImageCVMat(img, rot, CV_32F);
+        case 64:
+            return rotateImageCVMat(img, rot, CV_64F);
+        default:
+            return rotateImageCVMat(img.convertToFormat(QImage::Format_ARGB32), rot, CV_32F);
+        }
+#else
+        if (angle == 180) {
+            return img.mirrored(true, true);
+        }
+
+        QImage imgIn = img;
+
+        if (angle == 90) {
+            switch (imgIn.depth()) {
+            case 1:
+                imgIn = img.convertToFormat(QImage::Format_Indexed8);
+                return transposeImage<uint8_t>(imgIn).mirrored(true, false);
+            case 8:
+                return transposeImage<uint8_t>(imgIn).mirrored(true, false);
+            case 16:
+                return transposeImage<uint16_t>(imgIn).mirrored(true, false);
+            case 24:
+                return transposeImage24(imgIn).mirrored(true, false);
+            case 32:
+                return transposeImage<uint32_t>(imgIn).mirrored(true, false);
+            case 64:
+                return transposeImage<uint64_t>(imgIn).mirrored(true, false);
+            default:
+                imgIn = img.convertToFormat(QImage::Format_ARGB32);
+                return transposeImage<uint32_t>(imgIn).mirrored(true, false);
+            }
+        }
+
+        if (angle == 270) {
+            switch (imgIn.depth()) {
+            case 1:
+                imgIn = img.convertToFormat(QImage::Format_Indexed8);
+                return transposeImage<uint8_t>(imgIn.mirrored(true, false));
+            case 8:
+                return transposeImage<uint8_t>(imgIn.mirrored(true, false));
+            case 16:
+                return transposeImage<uint16_t>(imgIn.mirrored(true, false));
+            case 24:
+                return transposeImage24(imgIn.mirrored(true, false));
+            case 32:
+                return transposeImage<uint32_t>(imgIn.mirrored(true, false));
+            case 64:
+                return transposeImage<uint64_t>(imgIn.mirrored(true, false));
+            default:
+                imgIn = img.convertToFormat(QImage::Format_ARGB32);
+                return transposeImage<uint32_t>(imgIn.mirrored(true, false));
+            }
+        }
+#endif
+    }
+
+    return rotateImage(img, angle);
+}
+
 QImage DkImage::grayscaleImage(const QImage &img)
 {
     QImage imgR;
@@ -405,14 +573,6 @@ void DkImage::mapGammaTable(QImage &img, const QVector<uchar> &gammaTable)
     qDebug() << "gamma computation takes: " << dt;
 }
 
-QImage DkImage::normImage(const QImage &img)
-{
-    QImage imgN = img.copy();
-    normImage(imgN);
-
-    return imgN;
-}
-
 bool DkImage::normImage(QImage &img)
 {
     uchar maxVal = 0;
@@ -457,14 +617,6 @@ bool DkImage::normImage(QImage &img)
     return true;
 }
 
-QImage DkImage::autoAdjustImage(const QImage &img)
-{
-    QImage imgA = img.copy();
-    autoAdjustImage(imgA);
-
-    return imgA;
-}
-
 bool DkImage::autoAdjustImage(QImage &img)
 {
     // return DkImage::unsharpMask(img, 30.0f, 1.5f);
@@ -476,8 +628,7 @@ bool DkImage::autoAdjustImage(QImage &img)
     if (img.format() <= QImage::Format_Indexed8) {
         qDebug() << "[Auto Adjust] Grayscale - switching to Normalize: " << img.format();
         return normImage(img);
-    } else if (img.format() != QImage::Format_ARGB32 && img.format() != QImage::Format_ARGB32 && img.format() != QImage::Format_RGB32
-               && img.format() != QImage::Format_RGB888) {
+    } else if (img.format() != QImage::Format_ARGB32 && img.format() != QImage::Format_RGB32 && img.format() != QImage::Format_RGB888) {
         qDebug() << "[Auto Adjust] Format not supported: " << img.format();
         return false;
     }
@@ -831,7 +982,7 @@ QByteArray DkImage::extractImageFromDataStream(const QByteArray &ba, const QByte
     return bac;
 }
 
-QByteArray DkImage::fixSamsungPanorama(QByteArray &ba)
+bool DkImage::fixSamsungPanorama(QByteArray &ba)
 {
     // this code is based on python code from bcyrill
     // see: https://gist.github.com/bcyrill/e59fda6c7ffe23c7c4b08a990804b269
@@ -839,13 +990,13 @@ QByteArray DkImage::fixSamsungPanorama(QByteArray &ba)
     // see also: https://github.com/nomacs/nomacs/issues/254
 
     if (ba.size() < 8)
-        return QByteArray();
+        return false;
 
     QByteArray trailer = ba.right(4);
 
     // is it a samsung panorama jpg?
     if (trailer != QByteArray("SEFT"))
-        return QByteArray();
+        return false;
 
     // TODO saveify:
     int sefhPos = intFromByteArray(ba, ba.size() - 8) + 8;
@@ -853,7 +1004,7 @@ QByteArray DkImage::fixSamsungPanorama(QByteArray &ba)
 
     // trailer starts with "SEFH"?
     if (trailer.left(4) != QByteArray("SEFH"))
-        return QByteArray();
+        return false;
 
     int endPos = ba.size();
     int dirPos = endPos - sefhPos;
@@ -882,7 +1033,7 @@ QByteArray DkImage::fixSamsungPanorama(QByteArray &ba)
     }
 
     if (!isPano)
-        return QByteArray();
+        return false;
 
     int dataPos = dirPos - firstBlock;
 
@@ -893,7 +1044,8 @@ QByteArray DkImage::fixSamsungPanorama(QByteArray &ba)
     nb.append(ba.right(dataPos));
     qDebug() << "SAMSUNG panorma fix: EOI marker injected";
 
-    return nb;
+    ba = nb;
+    return true;
 }
 
 int DkImage::intFromByteArray(const QByteArray &ba, int pos)
@@ -1134,30 +1286,6 @@ QImage DkImage::mat2QImage(cv::Mat img)
     return qImg;
 }
 
-cv::Mat DkImage::get1DGauss(double sigma)
-{
-    // correct -> checked with matlab reference
-    int kernelsize = qCeil(sigma * 3 * 2) + 1;
-    if (kernelsize < 3)
-        kernelsize = 3;
-    if ((kernelsize % 2) != 1)
-        kernelsize += 1;
-
-    cv::Mat gKernel = cv::Mat(1, kernelsize, CV_32F);
-    float *kernelPtr = gKernel.ptr<float>();
-
-    for (int idx = 0, x = -qFloor(kernelsize / 2); idx < kernelsize; idx++, x++) {
-        kernelPtr[idx] = (float)(exp(-(x * x) / (2 * sigma * sigma))); // 1/(sqrt(2pi)*sigma) -> discrete normalization
-    }
-
-    if (sum(gKernel).val[0] != 0)
-        gKernel *= 1.0f / sum(gKernel).val[0];
-    else
-        qWarning() << "The kernel sum is zero\n";
-
-    return gKernel;
-}
-
 void DkImage::linearToGamma(cv::Mat &img)
 {
     QVector<unsigned short> gt = getLinear2GammaTable<unsigned short>();
@@ -1362,100 +1490,13 @@ QImage DkImage::createThumb(const QImage &image, int maxSize)
     return thumb;
 }
 
-// NOTE: this is just for fun (all images in the world : )
-bool DkImage::addToImage(QImage &img, unsigned char val)
-{
-    // number of bytes per line used
-    int bpl = (img.width() * img.depth() + 7) / 8;
-    int pad = img.bytesPerLine() - bpl;
-    uchar *ptr = img.bits();
-    bool done = false;
-
-    for (int rIdx = 0; rIdx < img.height(); rIdx++) {
-        for (int cIdx = 0; cIdx < bpl; cIdx++) {
-            // add it & we're done
-            if (*ptr <= 255 - val) {
-                *ptr += val;
-                done = true;
-                break;
-            }
-
-            int ov = *ptr + (int)val; // compute the overflow
-            val = (char)(ov - 255);
-
-            *ptr = val;
-            ptr++;
-        }
-
-        if (done)
-            break;
-
-        ptr += pad;
-    }
-
-    return done;
-}
-
-QColor DkImage::getMeanColor(const QImage &img)
-{
-    // some speed-up params
-    int nC = qRound(img.depth() / 8.0f);
-    int rStep = qRound(img.height() / 100.0f) + 1;
-    int cStep = qRound(img.width() / 100.0f) + 1;
-    int numCols = 42;
-
-    int offset = (nC > 1) ? 1 : 0; // no offset for grayscale images
-    QMap<QRgb, int> colLookup;
-    int maxColCount = 0;
-    QRgb maxCol = 0;
-
-    for (int rIdx = 0; rIdx < img.height(); rIdx += rStep) {
-        const unsigned char *pixel = img.constScanLine(rIdx);
-
-        for (int cIdx = 0; cIdx < img.width() * nC; cIdx += cStep * nC) {
-            QColor cColC(qRound(pixel[cIdx + 2 * offset] / 255.0f * numCols),
-                         qRound(pixel[cIdx + offset] / 255.0f * numCols),
-                         qRound(pixel[cIdx] / 255.0f * numCols));
-            QRgb cCol = cColC.rgb();
-
-            //// skip black
-            // if (cColC.saturation() < 10)
-            //	continue;
-            if (qRed(cCol) < 3 && qGreen(cCol) < 3 && qBlue(cCol) < 3)
-                continue;
-            if (qRed(cCol) > numCols - 3 && qGreen(cCol) > numCols - 3 && qBlue(cCol) > numCols - 3)
-                continue;
-
-            if (colLookup.contains(cCol)) {
-                colLookup[cCol]++;
-            } else
-                colLookup[cCol] = 1;
-
-            if (colLookup[cCol] > maxColCount) {
-                maxCol = cCol;
-                maxColCount = colLookup[cCol];
-            }
-        }
-    }
-
-    if (maxColCount > 0)
-        return QColor(qRound((float)qRed(maxCol) / numCols * 255), qRound((float)qGreen(maxCol) / numCols * 255), qRound((float)qBlue(maxCol) / numCols * 255));
-    else
-        return DkSettingsManager::param().display().hudBgColor;
-}
-
 // DkImageStorage --------------------------------------------------------------------
 DkImageStorage::DkImageStorage(const QImage &img)
 {
     mImg = img;
 
-    mWaitTimer = new QTimer(this);
-    mWaitTimer->setSingleShot(true);
-    mWaitTimer->setInterval(100);
-
     init();
 
-    connect(mWaitTimer, &QTimer::timeout, this, &DkImageStorage::compute, Qt::UniqueConnection);
     connect(&mFutureWatcher, &QFutureWatcher<QImage>::finished, this, &DkImageStorage::imageComputed, Qt::UniqueConnection);
     connect(DkActionManager::instance().action(DkActionManager::menu_view_anti_aliasing),
             &QAction::toggled,
@@ -1468,15 +1509,12 @@ void DkImageStorage::init()
 {
     mComputeState = l_not_computed;
     mScaledImg = QImage();
-    mWaitTimer->stop();
-    mSize = QSize();
 }
 
 void DkImageStorage::setImage(const QImage &img)
 {
-    init();
+    mScaledImg = QImage();
     mImg = img;
-
     mComputeState = l_cancelled;
 }
 
@@ -1500,55 +1538,45 @@ QImage DkImageStorage::image(const QSize &size)
 {
     if (size.isEmpty() || mImg.isNull() || !DkSettingsManager::param().display().antiAliasing || // user disabled?
         mImg.size().width() < size.width() // scale factor > 1?
-    )
+    ) {
         return mImg;
-
-    if (mScaledImg.size() == size)
-        return mScaledImg;
-
-    if (mComputeState != l_computing) {
-        // trigger a new computation
-        init();
-        mSize = size;
-        mWaitTimer->start();
     }
 
+    if (mScaledImg.size() == size) {
+        return mScaledImg;
+    }
+
+    // trigger a new computation
+    compute(size);
+
     // currently no alternative is available
     return mImg;
 }
 
-void DkImageStorage::cancel()
-{
-    mComputeState = l_cancelled;
-}
+QImage imageStorageScaleToSize(const QImage &src, const QSize &size);
 
-void DkImageStorage::compute()
+void DkImageStorage::compute(const QSize &size)
 {
-    if (mComputeState == l_computed) {
-        emit imageUpdated();
-        qDebug() << "image is up-to-date in DkImageStorage::compute...";
+    // don't compute twice
+    if (mComputeState == l_computing) {
         return;
     }
 
-    if (mComputeState == l_computing) // don't compute twice
-        return;
-
+    // Reset state
+    mScaledImg = QImage();
     mComputeState = l_computing;
 
-    mFutureWatcher.setFuture(QtConcurrent::run([&] {
-        return computeIntern(mImg, mSize);
-    }));
+    mFutureWatcher.setFuture(QtConcurrent::run(imageStorageScaleToSize, mImg, size));
 }
 
-QImage DkImageStorage::computeIntern(const QImage &src, const QSize &size)
+QImage imageStorageScaleToSize(const QImage &src, const QSize &size)
 {
     // should not happen
-    if (size.width() >= mImg.width()) {
-        qWarning() << "DkImageStorage::computeIntern was called without a need...";
+    if (size.width() >= src.width()) {
+        qWarning() << "imageStorageScaleToSize was called without a need...";
         return src;
     }
 
-    DkTimer dt;
     QImage resizedImg = src;
 
     if (!DkSettingsManager::param().display().highQualityAntiAliasing) {
@@ -1560,12 +1588,12 @@ QImage DkImageStorage::computeIntern(const QImage &src, const QSize &size)
         }
 
         // for extreme panorama images the Qt scaling crashes (if we have a width > 30000) so we simply
-        if (cs != mImg.size()) {
+        if (cs != src.size()) {
             resizedImg = resizedImg.scaled(cs, Qt::KeepAspectRatio, Qt::FastTransformation);
         }
     }
 
-    QSize s = mSize;
+    QSize s = size;
 
     if (s.height() == 0)
         s.setHeight(1);
@@ -1579,7 +1607,7 @@ QImage DkImageStorage::computeIntern(const QImage &src, const QSize &size)
         cv::resize(rImgCv, tmp, cv::Size(s.width(), s.height()), 0, 0, CV_INTER_AREA);
         resizedImg = DkImage::mat2QImage(tmp);
     } catch (...) {
-        qWarning() << "DkImageStorage: OpenCV exception caught while resizing...";
+        qWarning() << "imageStorageScaleToSize: OpenCV exception caught while resizing...";
     }
 #else
     resizedImg = resizedImg.scaled(s, Qt::KeepAspectRatio, Qt::SmoothTransformation);
