@@ -66,7 +66,7 @@ DkManipulatorWidget::DkManipulatorWidget(QWidget *parent)
     setObjectName("DkPreferenceTabs");
     createLayout();
 
-    for (QWidget *w : mWidgets)
+    for (auto w : mWidgets)
         w->setObjectName("darkManipulator");
 
     for (QAction *a : am.manipulatorActions())
@@ -85,12 +85,14 @@ void DkManipulatorWidget::createLayout()
     QButtonGroup *group = new QButtonGroup(this);
 
     DkActionManager &am = DkActionManager::instance();
-    // for (QAction* a : am.manipulatorActions()) {	// if you want to get all
     for (int idx = DkManipulatorManager::m_end; idx < DkManipulatorManager::m_ext_end; idx++) {
-        auto mpl = am.manipulatorManager().manipulatorExt((DkManipulatorManager::ManipulatorExtId)idx);
+        const auto extIdx = static_cast<DkManipulatorManager::ManipulatorExtId>(idx);
+        auto mpl = am.manipulatorManager().manipulatorExt(extIdx);
 
         DkTabEntryWidget *entry = new DkTabEntryWidget(mpl->action()->icon(), mpl->name(), this);
-        connect(entry, &DkTabEntryWidget::clicked, mpl->action(), &QAction::triggered, Qt::UniqueConnection);
+        connect(entry, &DkTabEntryWidget::clicked, this, [=]() {
+            selectManipulatorInner(mpl);
+        });
 
         aLayout->addWidget(entry);
         group->addButton(entry);
@@ -108,6 +110,7 @@ void DkManipulatorWidget::createLayout()
     actionScroller->setStyleSheet(scrollbarStyle + actionScroller->styleSheet());
     actionScroller->setWidgetResizable(true);
     actionScroller->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Preferred);
+    actionScroller->setMinimumWidth(300);
     actionScroller->setWidget(actionWidget);
     actionScroller->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 
@@ -116,69 +119,36 @@ void DkManipulatorWidget::createLayout()
     mTitleLabel->setObjectName("DkManipulatorSettingsTitle");
     mPreview = new QLabel(this);
     mPreview->setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
-
-    // undo
-    QPixmap pm = DkImage::colorizePixmap(QIcon(":/nomacs/img/rotate-cc.svg").pixmap(QSize(32, 32)), QColor(255, 255, 255));
-    QPushButton *undoButton = new QPushButton(pm, "", this);
-    undoButton->setFlat(true);
-    undoButton->setIconSize(QSize(32, 32));
-    undoButton->setObjectName("DkRestartButton");
-    undoButton->setStatusTip(tr("Undo"));
-    connect(undoButton, &QPushButton::clicked, am.action(DkActionManager::menu_edit_undo), &QAction::triggered);
-
-    pm = DkImage::colorizePixmap(QIcon(":/nomacs/img/rotate-cw.svg").pixmap(QSize(32, 32)), QColor(255, 255, 255));
-    QPushButton *redoButton = new QPushButton(pm, "", this);
-    redoButton->setFlat(true);
-    redoButton->setIconSize(QSize(32, 32));
-    redoButton->setObjectName("DkRestartButton");
-    redoButton->setStatusTip(tr("Redo"));
-    connect(redoButton, &QPushButton::clicked, am.action(DkActionManager::menu_edit_redo), &QAction::triggered);
-
-    QWidget *buttonWidget = new QWidget(this);
-    QHBoxLayout *buttonLayout = new QHBoxLayout(buttonWidget);
-    buttonLayout->setContentsMargins(0, 0, 0, 0);
-    buttonLayout->addWidget(undoButton);
-    buttonLayout->addWidget(redoButton);
+    mPreview->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+    mPreview->setContentsMargins(8, 8, 8, 8);
 
     QWidget *mplWidget = new QWidget(this);
     QVBoxLayout *mplLayout = new QVBoxLayout(mplWidget);
     mplLayout->setAlignment(Qt::AlignTop | Qt::AlignHCenter);
     mplLayout->addWidget(mTitleLabel);
-    for (QWidget *w : mWidgets)
+    for (auto w : mWidgets)
         mplLayout->addWidget(w);
     mplLayout->addWidget(mPreview);
-    mplLayout->addWidget(buttonWidget);
+    mplWidget->setMinimumHeight(350);
 
     QVBoxLayout *layout = new QVBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
+    layout->setSpacing(0);
     layout->addWidget(actionScroller);
     layout->addWidget(mplWidget);
 }
 
-QImage DkManipulatorWidget::scaledPreview(const QImage &img) const
-{
-    QImage imgR;
-
-    if (img.height() > img.width())
-        imgR = img.scaledToHeight(qMin(img.height(), mMaxPreview));
-    else
-        imgR = img.scaledToWidth(qMin(img.width(), mMaxPreview));
-
-    return imgR;
-}
-
 void DkManipulatorWidget::setImage(QSharedPointer<DkImageContainerT> imgC)
 {
-    mImgC = imgC;
-
-    if (mImgC) {
-        QImage img = mImgC->imageScaledToWidth(qMin(mPreview->width(), mMaxPreview));
-        img = scaledPreview(img);
-
+    if (imgC) {
+        QImage img = imgC->image();
+        QSize newSize = img.size().scaled(mPreview->contentsRect().size(), Qt::KeepAspectRatio);
+        img = img.scaledToWidth(newSize.width(), Qt::SmoothTransformation);
         mPreview->setPixmap(QPixmap::fromImage(img));
         mPreview->show();
-    } else
+    } else {
         mPreview->hide();
+    }
 }
 
 void DkManipulatorWidget::selectManipulator()
@@ -188,33 +158,35 @@ void DkManipulatorWidget::selectManipulator()
     DkActionManager &am = DkActionManager::instance();
     QSharedPointer<DkBaseManipulator> mpl = am.manipulatorManager().manipulator(action);
     QSharedPointer<DkBaseManipulatorExt> mplExt = qSharedPointerDynamicCast<DkBaseManipulatorExt>(mpl);
+    selectManipulatorInner(mplExt);
+}
 
-    // compute preview
-    if (mpl && mImgC) {
-        DkTimer dt;
-        QImage img = mpl->apply(mImgC->imageScaledToWidth(qMin(mPreview->width(), mMaxPreview)));
-        img = scaledPreview(img);
-
-        if (!img.isNull())
-            mPreview->setPixmap(QPixmap::fromImage(img));
-        qDebug() << "preview computed in " << dt;
-    }
-
-    for (QWidget *w : mWidgets)
-        w->hide();
-
+void DkManipulatorWidget::selectManipulatorInner(QSharedPointer<DkBaseManipulatorExt> mplExt)
+{
     if (!mplExt) {
         mTitleLabel->hide();
+        for (auto w : mWidgets) {
+            w->hide();
+        }
         return;
     }
 
     if (!mplExt->widget()) {
-        qCritical() << action->text() << "does not have a corresponding UI";
+        qCritical() << mplExt->name() << "does not have a corresponding UI";
         return;
     }
 
+    for (auto w : mWidgets) {
+        // Do not hide the target widget, otherwise we will lose focus
+        // if we are typing on the current widget.
+        if (w == mplExt->widget()) {
+            continue;
+        }
+        w->hide();
+    }
+
     mplExt->widget()->show();
-    mTitleLabel->setText(mpl->name());
+    mTitleLabel->setText(mplExt->name());
 }
 
 // DkMainpulatorDoc --------------------------------------------------------------------
