@@ -152,7 +152,6 @@ public slots:
     void openQuickLaunch();
     void openFileList();
     void saveFileList();
-    void renameFile();
     void changeSorting(bool change);
     void goTo();
     void find(bool filterAction = true);
@@ -278,7 +277,6 @@ protected:
 
     virtual void init();
 
-    void loadStyleSheet();
     virtual void createActions();
     virtual void createMenu();
     virtual void createContextMenu();
@@ -325,7 +323,6 @@ class DllCoreExport DkNoMacsFrameless : public DkNoMacs
 
 public:
     DkNoMacsFrameless(QWidget *parent = 0, Qt::WindowFlags flags = Qt::WindowFlags());
-
     virtual ~DkNoMacsFrameless();
 
 public slots:
@@ -334,6 +331,7 @@ public slots:
 protected:
     bool eventFilter(QObject *obj, QEvent *event) override;
     virtual void createContextMenu() override;
+    void paintEvent(QPaintEvent *event) override;
 };
 
 class DllCoreExport DkNoMacsContrast : public DkNoMacsSync
