@@ -568,9 +568,7 @@ void DkFilePreview::mouseMoveEvent(QMouseEvent *event)
                     // if (fileLabel->height() < height())
                     //	fileLabel->setText(thumbs.at(selected).getFile().fileName(), -1);
                     QFileInfo fileInfo(thumb->getFilePath());
-                    QString toolTipInfo = tr("Name: ") + fileInfo.fileName() + "\n" + tr("Size: ") + DkUtils::readableByte((float)fileInfo.size()) + "\n"
-                        + tr("Created: ") + fileInfo.birthTime().toString();
-                    setToolTip(toolTipInfo);
+                    setToolTip(thumb->toolTip());
                     setStatusTip(fileInfo.fileName());
                 }
                 break;
@@ -859,11 +857,7 @@ void DkThumbLabel::setThumb(QSharedPointer<DkThumbNailT> thumb)
         return;
 
     connect(thumb.data(), &DkThumbNailT::thumbLoadedSignal, this, &DkThumbLabel::updateLabel);
-    QFileInfo fileInfo(thumb->getFilePath());
-    QString toolTipInfo = tr("Name: ") + fileInfo.fileName() + "\n" + tr("Size: ") + DkUtils::readableByte((float)fileInfo.size()) + "\n" + tr("Created: ")
-        + fileInfo.birthTime().toString();
-
-    setToolTip(toolTipInfo);
+    setToolTip(thumb->toolTip());
 
     // style dummy
     mNoImagePen.setColor(QColor(150, 150, 150));
@@ -904,6 +898,8 @@ void DkThumbLabel::updateLabel()
     if (mThumb.isNull())
         return;
 
+    setToolTip(mThumb->toolTip());
+
     QPixmap pm;
 
     if (!mThumb->getImage().isNull()) {
@@ -929,7 +925,7 @@ void DkThumbLabel::updateLabel()
 
     QFont font;
     font.setBold(false);
-    font.setPointSize(8);
+    font.setPointSize(9); // two sizes smaller than default font see:stylesheet.css
     mText.setFont(font);
     mText.setPlainText(QFileInfo(mThumb->getFilePath()).fileName());
     mText.hide();
@@ -1177,6 +1173,7 @@ void DkThumbScene::setImageLoader(QSharedPointer<DkImageLoader> loader)
     connectLoader(mLoader, false); // disconnect
     mLoader = loader;
     connectLoader(loader);
+    showFile(""); // if we don't do this, then if the FIRST directory opened after startup is empty, no directory will be displayed in the status bar
 }
 
 void DkThumbScene::connectLoader(QSharedPointer<DkImageLoader> loader, bool connectSignals)
@@ -1222,21 +1219,37 @@ void DkThumbScene::keyPressEvent(QKeyEvent *event)
     }
 }
 
+void displayFileInfoInStatusbar(const QString &filePath)
+{
+    QFileInfo fInfo(filePath);
+    DkStatusBar *bar = DkStatusBarManager::instance().statusbar();
+    if (fInfo.exists()) {
+        bar->setMessage(DkUtils::readableByte(fInfo.size()), DkStatusBar::status_filesize_info);
+        bar->setMessage(filePath);
+    } else {
+        bar->setMessage("", DkStatusBar::status_filesize_info);
+    }
+}
+
 void DkThumbScene::showFile(const QString &filePath)
 {
-    if (filePath == QDir::currentPath() || filePath.isEmpty()) {
-        int sf = getSelectedFiles().size();
-
-        QString info;
-
-        if (sf > 1)
-            info = QString::number(sf) + tr(" selected");
-        else
-            info = QString::number(mThumbLabels.size()) + tr(" images");
-
-        DkStatusBarManager::instance().setMessage(tr("%1 | %2").arg(info, currentDir()));
-    } else
-        DkStatusBarManager::instance().setMessage(QFileInfo(filePath).fileName());
+    int sf = getSelectedFiles().size();
+    DkStatusBar *bar = DkStatusBarManager::instance().statusbar();
+    if (filePath == QDir::currentPath() || filePath.isEmpty()) { // i.e. user is NO LONGER hovering over a file
+        if (sf == 0) {
+            QString info = QString::number(mThumbLabels.size()) + tr(" images");
+            bar->setMessage(tr("%1 | %2").arg(info, currentDir()));
+            bar->setMessage("", DkStatusBar::status_filesize_info);
+        } else if (sf == 1) {
+            displayFileInfoInStatusbar(getSelectedFiles()[0]);
+        } else {
+            QString info = QString::number(sf) + tr(" selected");
+            bar->setMessage(tr("%1 | %2").arg(info, currentDir()));
+            bar->setMessage("", DkStatusBar::status_filesize_info);
+        }
+    } else { // i.e. user STARTED hovering over a file
+        displayFileInfoInStatusbar(filePath);
+    }
 }
 
 void DkThumbScene::ensureVisible(QSharedPointer<DkImageContainerT> img) const
@@ -1254,8 +1267,13 @@ void DkThumbScene::ensureVisible(QSharedPointer<DkImageContainerT> img) const
 
 QString DkThumbScene::currentDir() const
 {
-    if (mThumbs.empty() || !mThumbs[0])
-        return "";
+    if (mThumbs.empty() || !mThumbs[0]) {
+        if (mLoader) {
+            return mLoader->getDirPath();
+        } else { // should never happen
+            return "";
+        }
+    }
 
     return mThumbs[0]->fileInfo().absolutePath();
 }
@@ -1638,6 +1656,10 @@ void DkThumbsView::mousePressEvent(QMouseEvent *event)
     // otherwise so we just don't propagate this event
     if (itemClicked || event->modifiers() == Qt::NoModifier)
         QGraphicsView::mousePressEvent(event);
+
+    if (!itemClicked) {
+        scene->showFile("");
+    }
 }
 
 void DkThumbsView::mouseMoveEvent(QMouseEvent *event)
@@ -2037,7 +2059,7 @@ DkThumbPreviewLabel::DkThumbPreviewLabel(const QString &filePath, int thumbSize,
     QFileInfo fInfo(filePath);
     setToolTip(fInfo.fileName());
 
-    mThumb->fetchThumb(DkThumbNail::force_exif_thumb);
+    mThumb->fetchThumb(DkThumbNail::require_exif);
 }
 
 void DkThumbPreviewLabel::thumbLoaded()
