@@ -265,7 +265,7 @@ public slots:
     void selectThumb(int idx, bool select = true);
     void selectAllThumbs(bool select = true);
     void updateThumbs(QVector<QSharedPointer<DkImageContainerT>> thumbs);
-    void deleteSelected() const;
+    void deleteSelected();
     void copySelected() const;
     void pasteImages() const;
     void renameSelected() const;
@@ -283,6 +283,7 @@ protected:
     int mNumRows = 0;
     int mNumCols = 0;
     bool mFirstLayout = true;
+    int mLastSelectedIdx = -1; // last selected item to restore on updateThumbs()
 
     QVector<DkThumbLabel *> mThumbLabels;
     QSharedPointer<DkImageLoader> mLoader;
@@ -338,7 +339,7 @@ public slots:
     void setFilterFocus() const;
     void batchProcessFiles() const;
     void batchPrint() const;
-    void on_loadFile_triggered();
+    void onLoadFileTriggered();
 
 signals:
     void updateDirSignal(const QString &dir);
@@ -429,9 +430,9 @@ signals:
     void removeSignal();
 
 public slots:
-    void on_pin_clicked(bool checked);
-    void on_remove_clicked();
-    void on_load_dir_clicked();
+    void onPinClicked(bool checked);
+    void onRemoveClicked();
+    void onLoadDirClicked();
 
 protected:
     DkRecentDir mRecentDir;
