@@ -110,10 +110,6 @@ public:
     QSharedPointer<DkImageContainerT> imageContainer() const;
     void setImageLoader(QSharedPointer<DkImageLoader> newLoader);
     DkControlWidget *getController();
-    bool isTestLoaded()
-    {
-        return mTestLoaded;
-    };
 
     QString getCurrentPixelHexValue();
     QPoint mapToImage(const QPoint &windowPos) const;
@@ -129,7 +125,6 @@ signals:
     void zoomSignal(double zoomLevel) const;
     void mouseClickSignal(QMouseEvent *event, QPoint imgPos) const;
     void showProgress(bool show, int time = -1) const;
-    void imageUpdatedSignal() const;
 
 public slots:
     void fullView() override;
@@ -142,7 +137,6 @@ public slots:
     void deleteImage();
     void zoomToFit();
     void resizeEvent(QResizeEvent *event) override;
-    void toggleResetMatrix();
     void zoomTo(double zoomLevel);
 
     // tcp actions
@@ -172,6 +166,7 @@ public slots:
     void applyPlugin(DkPluginContainer *plugin, const QString &key);
 
     // image saving
+    bool isEdited() const;
     QImage getImage() const override;
     void saveFile();
     void saveFileAs(bool silent = false);
@@ -188,7 +183,8 @@ public slots:
     virtual void applyManipulator();
     void manipulatorApplied();
 
-    virtual void updateImage(QSharedPointer<DkImageContainerT> image, bool loaded = true);
+    void updateLoadedImage();
+    void onImageLoaded(QSharedPointer<DkImageContainerT> image, bool loaded = true);
     virtual void setImageUpdated();
     virtual void loadImage(const QImage &newImg);
     virtual void loadImage(QSharedPointer<DkImageContainerT> img);
@@ -219,6 +215,7 @@ protected:
 
     bool mTestLoaded = false;
     bool mGestureStarted = false;
+    bool mDisabledBackground = false; // disables drawBackground() (frameless dialog)
 
     QRectF mOldImgRect;
 
