@@ -51,31 +51,36 @@
 #include <QObject>
 #include <QProcess>
 #include <QTextStream>
+#include <QThread>
 #include <QTranslator>
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <QImageReader>
+#endif
+
 #pragma warning(pop) // no warnings from includes - end
 
 #include "DkCentralWidget.h"
+#include "DkDependencyResolver.h"
+#include "DkMetaData.h"
 #include "DkNoMacs.h"
 #include "DkPluginManager.h"
 #include "DkPong.h"
 #include "DkProcess.h"
 #include "DkSettings.h"
+#include "DkThemeManager.h"
 #include "DkTimer.h"
 #include "DkUtils.h"
-
-#include "DkDependencyResolver.h"
-#include "DkMetaData.h"
-
 #include "DkVersion.h"
+#include "DkViewPort.h"
 
 #include <cassert>
 #include <iostream>
 
-#ifdef Q_OS_WIN
+#ifdef _MSC_BUILD
 #include <shlobj.h>
 #endif
 
-#ifdef Q_OS_WIN
+#ifdef _MSC_BUILD
 int main(int argc, wchar_t *argv[])
 {
 #else
@@ -88,19 +93,26 @@ int main(int argc, char *argv[])
     QCoreApplication::setApplicationName("Image Lounge");
     QCoreApplication::setApplicationVersion(NOMACS_VERSION_STR);
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
     QApplication::setAttribute(Qt::AA_DisableHighDpiScaling, true);
+
+#ifdef Q_OS_MAC
+    QApplication::setAttribute(Qt::AA_DontShowIconsInMenus, true);
 #endif
 
     QApplication app(argc, (char **)argv);
 
+#ifdef Q_OS_LINUX
+    app.setDesktopFileName("org.nomacs.ImageLounge");
+#endif
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    QImageReader::setAllocationLimit(2048);
+#endif
+
     // init settings
     nmc::DkSettingsManager::instance().init();
     nmc::DkMetaDataHelper::initialize(); // this line makes the XmpParser thread-save - so don't delete it even if you seem to know what you do
 
-    nmc::DefaultSettings settings;
-    int mode = settings.value("AppSettings/appMode", nmc::DkSettingsManager::param().app().appMode).toInt();
-
     // uncomment this for the single instance feature...
     //// check for single instance
     // nmc::DkRunGuard guard;
@@ -202,8 +214,8 @@ int main(int argc, char *argv[])
         return 0;
 
     // install translations
-    QString translationName = "nomacs_" + settings.value("GlobalSettings/language", nmc::DkSettingsManager::param().global().language).toString() + ".qm";
-    QString translationNameQt = "qt_" + settings.value("GlobalSettings/language", nmc::DkSettingsManager::param().global().language).toString() + ".qm";
+    const QString translationName = "nomacs_" + nmc::DkSettingsManager::param().global().language + ".qm";
+    const QString translationNameQt = "qt_" + nmc::DkSettingsManager::param().global().language + ".qm";
 
     QTranslator translator;
     nmc::DkSettingsManager::param().loadTranslation(translationName, translator);
@@ -216,48 +228,89 @@ int main(int argc, char *argv[])
     nmc::DkNoMacs *w = 0;
     nmc::DkPong *pw = 0; // pong
 
-    // show pink icons if nomacs is in private mode
-    if (parser.isSet(privateOpt)) {
-        nmc::DkSettingsManager::param().display().iconColor = QColor(136, 0, 125);
+    if (parser.isSet(privateOpt))
         nmc::DkSettingsManager::param().app().privateMode = true;
-    }
+
+    int mode = nmc::DkSettingsManager::param().app().appMode;
+    qInfo() << "loaded app mode:" << mode;
 
     if (parser.isSet(modeOpt)) {
         QString pm = parser.value(modeOpt);
 
         if (pm == "default")
-            mode = nmc::DkSettingsManager::param().mode_default;
+            mode = nmc::DkSettings::mode_default;
         else if (pm == "frameless")
-            mode = nmc::DkSettingsManager::param().mode_frameless;
+            mode = nmc::DkSettings::mode_frameless;
         else if (pm == "pseudocolor")
-            mode = nmc::DkSettingsManager::param().mode_contrast;
+            mode = nmc::DkSettings::mode_contrast;
         else
             qWarning() << "illegal mode: " << pm << "use either <default>, <frameless> or <pseudocolor>";
-
-        nmc::DkSettingsManager::param().app().currentAppMode = mode;
     }
 
+    if (parser.isSet(fullScreenOpt))
+        mode = nmc::DkSettings::fullscreenMode(mode);
+
+    if (!nmc::DkSettings::modeIsValid(mode)) {
+        qWarning() << "invalid mode:" << mode;
+        mode = nmc::DkSettings::mode_default;
+    }
+
+    // TODO: currentAppMode is obsolete now; use appMode instead
+    // currentAppMode is not saved/restored by settings but must be set early
+    nmc::DkSettingsManager::param().app().currentAppMode = mode;
+
     nmc::DkTimer dt;
 
+    // bring up theme before any widgets
+    nmc::DkThemeManager::instance().applyTheme();
+
     // initialize nomacs
-    if (mode == nmc::DkSettingsManager::param().mode_frameless) {
+    const int modeType = nmc::DkSettings::normalMode(mode);
+    if (modeType == nmc::DkSettings::mode_frameless) {
         w = new nmc::DkNoMacsFrameless();
         qDebug() << "this is the frameless nomacs...";
-    } else if (mode == nmc::DkSettingsManager::param().mode_contrast) {
+    } else if (modeType == nmc::DkSettings::mode_contrast) {
         w = new nmc::DkNoMacsContrast();
         qDebug() << "this is the contrast nomacs...";
     } else if (parser.isSet(pongOpt)) {
         pw = new nmc::DkPong();
         int rVal = app.exec();
         return rVal;
-    } else
+    } else {
         w = new nmc::DkNoMacsIpl();
+    }
 
-    // show what we got...
-    w->show();
+    qInfo() << "init window: appMode:" << nmc::DkSettingsManager::param().app().currentAppMode << "maximized:" << w->isMaximized()
+            << "fullscreen:" << w->isFullScreen() << "geometry:" << w->geometry() << "windowState:" << w->windowState();
 
-    // this triggers a first show
-    QCoreApplication::sendPostedEvents();
+    if (nmc::DkSettings::modeIsFullscreen(mode))
+        w->showFullScreen();
+    else if (w->windowState() & Qt::WindowMaximized)
+        w->showMaximized();
+    else
+        w->showNormal();
+
+    const bool maximized = w->isMaximized(); // check if show* actually maximized us
+
+    qInfo() << "show window: appMode:" << nmc::DkSettingsManager::param().app().currentAppMode << "maximized:" << w->isMaximized()
+            << "fullscreen:" << w->isFullScreen() << "geometry:" << w->geometry() << "windowState:" << w->windowState();
+
+    while (!w->isActiveWindow() && dt.elapsed() < 5000) {
+        qDebug() << "waiting for active window";
+        QThread::msleep(10);
+        qApp->processEvents();
+    }
+
+    qInfo() << "active window: appMode:" << nmc::DkSettingsManager::param().app().currentAppMode << "maximized:" << w->isMaximized()
+            << "fullscreen:" << w->isFullScreen() << "geometry:" << w->geometry() << "windowState:" << w->windowState();
+
+    qInfo() << "window font:" << w->font();
+    qInfo() << "system font:" << qApp->font();
+
+    // Qt emulates showMaximized() on some platforms (X11), so it might not work.
+    // If we try again with a visible window, it *could* work correctly (GNOME)
+    if (maximized && !w->isMaximized())
+        w->showMaximized();
 
     if (w)
         w->onWindowLoaded();
@@ -293,26 +346,23 @@ int main(int argc, char *argv[])
     }
 
     // load recent files if there is nothing to display
-    if (!loading && nmc::DkSettingsManager::param().app().showRecentFiles) {
+    if (!loading && nmc::DkSettingsManager::param().app().showRecentFiles)
         w->showRecentFilesOnStartUp();
-    }
 
-    int fullScreenMode = settings.value("AppSettings/currentAppMode", nmc::DkSettingsManager::param().app().currentAppMode).toInt();
-
-    if (fullScreenMode == nmc::DkSettingsManager::param().mode_default_fullscreen || fullScreenMode == nmc::DkSettingsManager::param().mode_frameless_fullscreen
-        || fullScreenMode == nmc::DkSettingsManager::param().mode_contrast_fullscreen || parser.isSet(fullScreenOpt)) {
+    if (w->isFullScreen())
         w->enterFullScreen();
-        qDebug() << "trying to enter fullscreen...";
-    }
 
-    if (parser.isSet(slideshowOpt)) {
+    if (parser.isSet(slideshowOpt))
         cw->startSlideshow();
-    }
 
-#ifdef Q_WS_MAC
+    if (cw->hasViewPort())
+        cw->getViewPort()->setFocus(Qt::TabFocusReason);
+
+// since Qt5 only Q_OS_MACOS is defined, see https://doc.qt.io/qt-5/macos-issues.html#compile-time-flags
+#ifdef Q_OS_MACOS
     nmc::DkNomacsOSXEventFilter *osxEventFilter = new nmc::DkNomacsOSXEventFilter();
     app.installEventFilter(osxEventFilter);
-    QObject::connect(osxEventFilter, SIGNAL(loadFile(const QFileInfo &)), w, SLOT(loadFile(const QFileInfo &)));
+    QObject::connect(osxEventFilter, &nmc::DkNomacsOSXEventFilter::loadFile, w, &nmc::DkNoMacs::loadFile);
 #endif
 
     int rVal = -1;
